word_gsl1 = {"a",
"an",
"able",
"ability",
"abler",
"ablest",
"ably",
"abilities",
"unable",
"inability",
"about",
"above",
"accept",
"acceptability",
"acceptable",
"unacceptable",
"acceptance",
"accepted",
"accepting",
"accepts",
"accord",
"accorded",
"accordance",
"according",
"accordingly",
"accords",
"account",
"accounted",
"accounting",
"accounts",
"accountant",
"accountants",
"accountancy",
"accountable",
"accountability",
"across",
"act",
"acted",
"acting",
"action",
"actions",
"acts",
"active",
"actively",
"activities",
"activity",
"actor",
"actors",
"actress",
"actresses",
"actual",
"actually",
"add",
"added",
"adding",
"addition",
"additional",
"additive",
"additions",
"adds",
"address",
"addressed",
"addresses",
"addressing",
"admit",
"admission",
"admittedly",
"admits",
"admitted",
"admitting",
"adopt",
"adopted",
"adopting",
"adoption",
"adoptions",
"adopts",
"advance",
"advanced",
"advances",
"advancement",
"advancing",
"advantage",
"advantages",
"disadvantage",
"disadvantages",
"advantaging",
"advantaged",
"disadvantaged",
"adventure",
"adventures",
"adventurer",
"adventurers",
"adventurous",
"affair",
"affairs",
"after",
"afterwards",
"again",
"against",
"age",
"aged",
"ages",
"aging",
"agent",
"agency",
"agencies",
"agents",
"ago",
"agree",
"agreed",
"agreeing",
"agreement",
"agreements",
"agrees",
"agreeable",
"disagreements",
"disagree",
"disagreeable",
"disagreed",
"disagreeing",
"disagreement",
"disagrees",
"air",
"all",
"allow",
"allowance",
"allowances",
"allowed",
"allowing",
"allows",
"almost",
"alone",
"along",
"already",
"also",
"although",
"always",
"among",
"amongst",
"amount",
"amounted",
"amounting",
"amounts",
"ancient",
"and",
"animal",
"animals",
"another",
"answer",
"answered",
"answering",
"answers",
"any",
"anybody",
"anyhow",
"anymore",
"anyone",
"anything",
"anyway",
"anywhere",
"appear",
"appearance",
"appeared",
"appearing",
"appears",
"appearances",
"disappearances",
"disappear",
"disappearance",
"disappeared",
"disappearing",
"disappears",
"apply",
"application",
"applications",
"applied",
"applies",
"applicable",
"applying",
"applicant",
"applicants",
"applicability",
"appoint",
"appointed",
"appointing",
"appointments",
"appointment",
"appoints",
"april",
"arise",
"arisen",
"arises",
"arose",
"arising",
"arm",
"armed",
"arms",
"unarmed",
"army",
"armies",
"around",
"arrive",
"arrival",
"arrivals",
"arrived",
"arrives",
"arriving",
"art",
"arts",
"artist",
"artistic",
"artists",
"artistically",
"article",
"articles",
"as",
"ask",
"asked",
"asking",
"asks",
"associate",
"associations",
"association",
"associating",
"associates",
"associated",
"disassociate",
"disassociated",
"at",
"attack",
"attacked",
"attacking",
"attacks",
"attempt",
"attempted",
"attempting",
"attempts",
"august",
"average",
"averaged",
"averages",
"averaging",
"away",
"b",
"back",
"backed",
"background",
"backing",
"backs",
"backbone",
"backgrounds",
"backwards",
"backward",
"bad",
"badly",
"badness",
"ball",
"balls",
"bank",
"banked",
"banker",
"bankers",
"banking",
"banks",
"bar",
"bars",
"barred",
"barring",
"base",
"based",
"bases",
"basic",
"basically",
"basing",
"basis",
"battle",
"battled",
"battles",
"battling",
"be",
"am",
"are",
"been",
"is",
"re",
"s",
"was",
"were",
"being",
"beings",
"bear",
"bearing",
"bearings",
"bears",
"bore",
"born",
"borne",
"beauty",
"beautiful",
"beautifully",
"because",
"become",
"became",
"becomes",
"becoming",
"bed",
"bedroom",
"bedrooms",
"bedding",
"beds",
"before",
"begin",
"began",
"beginner",
"beginners",
"beginning",
"beginnings",
"begins",
"begun",
"behind",
"believe",
"belief",
"beliefs",
"believed",
"believes",
"believing",
"disbelief",
"belong",
"belonged",
"belonging",
"belongings",
"belongs",
"below",
"beneath",
"beside",
"besides",
"best",
"better",
"between",
"beyond",
"big",
"bigger",
"biggest",
"biggish",
"bill",
"bills",
"billed",
"billing",
"bird",
"birds",
"black",
"blacker",
"blackest",
"blackly",
"blacken",
"blackness",
"blacks",
"blackish",
"blood",
"bled",
"bleed",
"bleeding",
"bleeds",
"bloody",
"blow",
"blew",
"blowing",
"blows",
"blown",
"blue",
"blueness",
"bluer",
"bluest",
"board",
"boarded",
"boarding",
"boards",
"boat",
"boats",
"body",
"bodies",
"bodily",
"book",
"books",
"both",
"box",
"boxes",
"boy",
"boyhood",
"boys",
"branch",
"branches",
"branched",
"branching",
"bread",
"break",
"breaking",
"breakage",
"breaks",
"broke",
"broken",
"unbreakable",
"outbreaks",
"outbreak",
"unbroken",
"bridge",
"bridges",
"bright",
"brighten",
"brightened",
"brightening",
"brightens",
"brighter",
"brightest",
"brightly",
"brightness",
"bring",
"bringing",
"brings",
"brought",
"broad",
"broadly",
"breadth",
"broader",
"broadest",
"brother",
"brothers",
"brotherly",
"build",
"build-up",
"builders",
"building",
"buildings",
"builds",
"built",
"burn",
"burned",
"burning",
"burns",
"burnt",
"business",
"businesses",
"businessmen",
"businesslike",
"businessman",
"businesswoman",
"businesswomen",
"but",
"buy",
"bought",
"buying",
"buys",
"buyer",
"buyers",
"by",
"c",
"call",
"called",
"calling",
"calls",
"can",
"cannot",
"cans",
"canned",
"canning",
"capital",
"capitals",
"captain",
"captains",
"car",
"cars",
"care",
"cared",
"careful",
"carefully",
"careless",
"cares",
"caring",
"carelessly",
"carry",
"carried",
"carries",
"carrying",
"case",
"cases",
"castle",
"castles",
"catch",
"catches",
"catching",
"caught",
"cause",
"caused",
"causes",
"causing",
"centre",
"center",
"centers",
"centred",
"centered",
"central",
"centralization",
"centres",
"centrist",
"centrists",
"certain",
"certainly",
"certainty",
"uncertain",
"uncertainties",
"uncertainty",
"chance",
"chanced",
"chances",
"chancing",
"change",
"changed",
"changes",
"changing",
"unchanged",
"unchangeable",
"unchanging",
"character",
"characteristic",
"characteristically",
"characteristics",
"characterize",
"characterized",
"characterization",
"characterizes",
"characterise",
"characterised",
"characterises",
"characters",
"charge",
"charged",
"charges",
"charging",
"chief",
"chiefs",
"chiefly",
"child",
"children",
"childish",
"childhood",
"childlike",
"choose",
"choice",
"choices",
"chooses",
"choosing",
"chose",
"chosen",
"church",
"churches",
"circle",
"circled",
"circles",
"circling",
"circular",
"city",
"cities",
"citizen",
"citizens",
"claim",
"claimed",
"claiming",
"claims",
"unclaimed",
"class",
"classed",
"classes",
"classing",
"classify",
"classifying",
"classified",
"classifies",
"classification",
"classifications",
"clear",
"cleared",
"clearer",
"clearest",
"clearing",
"clearings",
"clearly",
"clearness",
"clears",
"close",
"closed",
"closely",
"closeness",
"closer",
"closes",
"closest",
"closure",
"closing",
"cloud",
"cloudy",
"clouded",
"clouds",
"coal",
"coast",
"coasts",
"coin",
"coins",
"cold",
"colder",
"coldest",
"coldly",
"coldness",
"colds",
"college",
"colleges",
"colony",
"colonial",
"colonies",
"colonials",
"colonize",
"colonization",
"colonized",
"colonising",
"colonist",
"colonists",
"colour",
"color",
"colored",
"colorful",
"coloring",
"colorless",
"colors",
"coloured",
"colourful",
"colouring",
"colourless",
"colours",
"come",
"came",
"comes",
"coming",
"command",
"commanded",
"commanding",
"commands",
"commander",
"commanders",
"committee",
"committees",
"common",
"commoner",
"commonest",
"commonly",
"commonness",
"commons",
"uncommon",
"uncommonly",
"company",
"companies",
"complete",
"completed",
"completely",
"completion",
"completions",
"completes",
"completeness",
"completing",
"incomplete",
"incompletely",
"concern",
"concerned",
"concerning",
"concerns",
"unconcerned",
"condition",
"conditional",
"conditions",
"unconditional",
"consider",
"consideration",
"considerations",
"considered",
"considering",
"considers",
"reconsider",
"reconsidering",
"reconsideration",
"contain",
"contained",
"container",
"containers",
"containing",
"contains",
"content",
"contented",
"contenting",
"contentment",
"contents",
"discontent",
"discontentment",
"continue",
"continuance",
"continued",
"continuity",
"continues",
"continuing",
"continuous",
"continuously",
"control",
"controlled",
"controller",
"controlling",
"controls",
"uncontrollable",
"uncontrollably",
"uncontrolled",
"corn",
"cost",
"costing",
"costs",
"costly",
"cotton",
"could",
"council",
"councillor",
"councillors",
"councilor",
"councils",
"count",
"counted",
"counting",
"countless",
"counts",
"countable",
"uncountable",
"country",
"countries",
"course",
"courses",
"court",
"courts",
"cover",
"covered",
"covering",
"coverage",
"covers",
"uncover",
"uncovered",
"uncovers",
"cross",
"crossed",
"crosses",
"crossing",
"crowd",
"crowded",
"crowding",
"crowds",
"crown",
"crowns",
"crowned",
"crowning",
"uncrowned",
"cry",
"cried",
"cries",
"crying",
"current",
"currently",
"cut",
"cuts",
"cutting",
"uncut",
"d",
"danger",
"dangerous",
"dangerously",
"dangers",
"dark",
"darker",
"darkest",
"darkness",
"date",
"dates",
"dated",
"dating",
"daughter",
"daughters",
"day",
"daily",
"daylight",
"days",
"dead",
"death",
"deaths",
"deal",
"dealer",
"dealers",
"dealing",
"dealings",
"deals",
"dealt",
"dear",
"dears",
"december",
"decide",
"decided",
"decidedly",
"decides",
"deciding",
"decision",
"decisions",
"decisive",
"undecided",
"declare",
"declaration",
"declarations",
"declared",
"declares",
"declaring",
"deep",
"deepen",
"deepened",
"deeper",
"deepest",
"deeply",
"depth",
"depths",
"deepening",
"defeat",
"defeated",
"defeats",
"defeating",
"undefeated",
"degree",
"degrees",
"demand",
"demanded",
"demanding",
"demands",
"department",
"departments",
"departmental",
"depend",
"depends",
"depended",
"depending",
"dependant",
"dependants",
"dependent",
"describe",
"described",
"describes",
"describing",
"description",
"descriptions",
"descriptive",
"desert",
"deserted",
"deserting",
"deserts",
"desire",
"desired",
"desirability",
"desirable",
"desires",
"desiring",
"undesirable",
"destroy",
"destroyed",
"destroying",
"destroys",
"destruction",
"destructive",
"detail",
"detailed",
"detailing",
"details",
"determine",
"determination",
"determined",
"indeterminate",
"determinate",
"determines",
"determining",
"develop",
"developed",
"developers",
"developing",
"development",
"developments",
"develops",
"underdeveloped",
"undeveloped",
"die",
"died",
"dies",
"dying",
"undying",
"difference",
"differ",
"differences",
"different",
"differs",
"differing",
"differently",
"difficult",
"difficulties",
"difficulty",
"direct",
"directed",
"directing",
"direction",
"directions",
"directly",
"director",
"directors",
"directs",
"indirect",
"indirectly",
"discover",
"discovered",
"discoveries",
"discovering",
"discovers",
"discovery",
"distance",
"distances",
"distant",
"distanced",
"distancing",
"distinguish",
"distinguished",
"distinguishes",
"distinguishing",
"distinguishable",
"district",
"districts",
"divide",
"divided",
"divides",
"dividing",
"division",
"divisions",
"undivided",
"do",
"did",
"does",
"doing",
"don",
"done",
"doctor",
"doctors",
"dr",
"dog",
"dogs",
"dogged",
"dollar",
"dollars",
"door",
"doors",
"indoors",
"outdoors",
"doubt",
"doubted",
"doubtful",
"doubting",
"doubtless",
"undoubtedly",
"doubts",
"down",
"downwards",
"draw",
"drawing",
"drawn",
"draws",
"drew",
"dream",
"dreamed",
"dreaming",
"dreams",
"dreamt",
"dreamy",
"dress",
"dressed",
"dresses",
"dressing",
"undressed",
"drink",
"drinks",
"drinker",
"drinkers",
"drank",
"drunk",
"drinking",
"drive",
"driven",
"driver",
"drivers",
"drives",
"driveway",
"driving",
"drove",
"drop",
"dropped",
"dropping",
"drops",
"dry",
"dried",
"dries",
"driest",
"dryer",
"drying",
"dryly",
"dryness",
"due",
"duty",
"duties",
"e",
"each",
"ear",
"ears",
"early",
"earlier",
"earliest",
"earliness",
"earth",
"earthy",
"earthquake",
"earthquakes",
"east",
"eastern",
"easy",
"easier",
"easiest",
"easily",
"easiness",
"eat",
"ate",
"eaten",
"eating",
"eats",
"effect",
"effected",
"effecting",
"effective",
"effectively",
"effectiveness",
"effects",
"ineffective",
"ineffectively",
"efficient",
"efficiency",
"inefficient",
"effort",
"efforts",
"egg",
"eggs",
"eight",
"eighteen",
"eighteenth",
"eighth",
"eighties",
"eightieth",
"eighty",
"eights",
"th",
"either",
"elect",
"elected",
"electing",
"election",
"elections",
"elects",
"electors",
"electoral",
"eleven",
"elevens",
"eleventh",
"else",
"elsewhere",
"empire",
"empires",
"employ",
"employed",
"employee",
"employees",
"employer",
"employers",
"employing",
"employment",
"employs",
"unemployed",
"unemployment",
"end",
"ended",
"ending",
"endless",
"endlessly",
"ends",
"enemy",
"enemies",
"english",
"enjoy",
"enjoyed",
"enjoying",
"enjoyment",
"enjoys",
"enjoyable",
"enough",
"enter",
"entered",
"entering",
"enters",
"entrance",
"entrances",
"entries",
"entry",
"equal",
"equaled",
"equaling",
"equality",
"equalled",
"equalling",
"equally",
"equals",
"inequality",
"unequal",
"escape",
"escaped",
"escapes",
"escaping",
"even",
"evenly",
"evening",
"evenings",
"event",
"events",
"ever",
"every",
"everybody",
"everyday",
"everyone",
"everything",
"everywhere",
"example",
"examples",
"except",
"exception",
"exceptional",
"exceptions",
"exchange",
"exchanged",
"exchanges",
"exchanging",
"exercise",
"exercised",
"exercises",
"exercising",
"exist",
"existed",
"existence",
"existing",
"exists",
"nonexistent",
"expect",
"expectancy",
"expectation",
"expectations",
"expected",
"expecting",
"expects",
"expense",
"expenses",
"expensive",
"experience",
"experienced",
"experiences",
"experiencing",
"experiment",
"experimental",
"experimentation",
"experimented",
"experimenting",
"experiments",
"explain",
"explained",
"explaining",
"explains",
"explanation",
"explanatory",
"explanations",
"express",
"expressed",
"expresses",
"expressing",
"expression",
"expressions",
"expressive",
"extend",
"extended",
"extending",
"extends",
"extension",
"extensions",
"extensive",
"extensively",
"extent",
"eye",
"eyes",
"f",
"face",
"faced",
"faces",
"facing",
"fact",
"facts",
"factual",
"factory",
"factories",
"fail",
"failed",
"failing",
"fails",
"failure",
"failures",
"fair",
"fairer",
"fairest",
"fairly",
"fairness",
"unfair",
"unfairly",
"faith",
"faithful",
"faithfully",
"faiths",
"fall",
"fallen",
"falling",
"falls",
"fell",
"familiar",
"familiarity",
"unfamiliar",
"unfamiliarity",
"familiarly",
"family",
"families",
"famous",
"far",
"farther",
"farthest",
"further",
"furthest",
"farm",
"farmer",
"farmers",
"farms",
"farming",
"fast",
"faster",
"fastest",
"fastness",
"father",
"fathers",
"dad",
"dads",
"father-in-law",
"favour",
"favor",
"favorite",
"favourite",
"favourable",
"favourably",
"favoured",
"favouring",
"favourites",
"favours",
"fear",
"feared",
"fearful",
"fearing",
"fears",
"february",
"feel",
"feeling",
"feelings",
"feels",
"felt",
"fellow",
"fellows",
"few",
"fewer",
"fewest",
"field",
"fields",
"fight",
"fighter",
"fighters",
"fighting",
"fought",
"fights",
"figure",
"figures",
"fill",
"filled",
"filling",
"fills",
"find",
"finding",
"findings",
"finds",
"found",
"fine",
"finely",
"fineness",
"finer",
"finest",
"finish",
"finished",
"finishes",
"finishing",
"unfinished",
"fire",
"fired",
"fires",
"firing",
"first",
"firstly",
"fish",
"fished",
"fishes",
"fishing",
"fisherman",
"fit",
"fitness",
"fits",
"fitted",
"fitter",
"fittest",
"fitting",
"five",
"fives",
"fifteen",
"fifteenth",
"fifth",
"fifthly",
"fifties",
"fiftieth",
"fifty",
"fix",
"fixed",
"fixes",
"fixing",
"fixable",
"floor",
"floors",
"flow",
"flowed",
"flows",
"flowing",
"flower",
"flowers",
"fly",
"flew",
"flown",
"flying",
"flight",
"flights",
"flies",
"follow",
"followed",
"follower",
"followers",
"following",
"follows",
"food",
"foods",
"for",
"force",
"forced",
"forces",
"forcing",
"forceful",
"forcefully",
"foreign",
"foreigner",
"foreigners",
"forest",
"forests",
"foresting",
"forested",
"forget",
"forgets",
"forgetting",
"forgot",
"forgotten",
"unforgettable",
"form",
"formation",
"formed",
"forming",
"forms",
"former",
"formerly",
"forth",
"fortune",
"fortunate",
"fortunately",
"fortunes",
"unfortunately",
"unfortunate",
"four",
"fours",
"forties",
"forty",
"fourteen",
"fourteenth",
"fourth",
"fourthly",
"fortieth",
"free",
"freed",
"freedom",
"freedoms",
"freeing",
"freely",
"freer",
"freest",
"fresh",
"freshness",
"fresher",
"freshest",
"freshly",
"friday",
"fri",
"fridays",
"friend",
"friendly",
"friends",
"friendship",
"friendships",
"from",
"front",
"full",
"fuller",
"fullest",
"fullness",
"fully",
"furnish",
"furnishes",
"furnished",
"furnishing",
"furniture",
"future",
"futures",
"g",
"gain",
"gained",
"gaining",
"gains",
"game",
"games",
"garden",
"gardener",
"gardeners",
"gardens",
"gas",
"gases",
"gate",
"gates",
"gather",
"gathered",
"gathering",
"gatherings",
"gathers",
"general",
"generally",
"generals",
"generalise",
"generalisable",
"generalised",
"generalisation",
"generalisations",
"generality",
"generalizations",
"gentle",
"gentleman",
"gentlemen",
"gently",
"get",
"gets",
"getting",
"got",
"gotten",
"gift",
"gifts",
"gifted",
"girl",
"girls",
"give",
"gave",
"given",
"gives",
"giving",
"glad",
"gladder",
"gladdest",
"gladly",
"gladness",
"glass",
"glasses",
"go",
"goes",
"going",
"gone",
"went",
"god",
"gods",
"goddess",
"gold",
"golden",
"good",
"goodbye",
"goodbyes",
"goodness",
"great",
"greater",
"greatest",
"greatly",
"greatness",
"green",
"greener",
"greenest",
"greenness",
"greenish",
"ground",
"grounded",
"grounds",
"grounding",
"group",
"grouped",
"grouping",
"groupings",
"groups",
"grow",
"grew",
"growing",
"grown",
"grows",
"growth",
"h",
"half",
"halves",
"hand",
"handed",
"handful",
"handfuls",
"handing",
"hands",
"handwriting",
"hang",
"hanged",
"hanging",
"hangs",
"hung",
"happen",
"happened",
"happening",
"happens",
"happy",
"happier",
"happiest",
"happily",
"happiness",
"unhappy",
"hard",
"harden",
"hardened",
"hardening",
"hardens",
"harder",
"hardest",
"hardness",
"hardship",
"hardships",
"hardly",
"have",
"had",
"has",
"haven",
"haves",
"having",
"he",
"him",
"himself",
"his",
"head",
"headed",
"heading",
"heads",
"hear",
"heard",
"hearer",
"hearing",
"hears",
"heart",
"hearts",
"heat",
"heated",
"heating",
"heats",
"heaven",
"heavenly",
"heavens",
"heavy",
"heavier",
"heaviest",
"heavily",
"help",
"helped",
"helpful",
"helping",
"helpless",
"helplessly",
"helps",
"helper",
"helpers",
"here",
"high",
"higher",
"highest",
"highly",
"highness",
"highway",
"highways",
"hill",
"hills",
"hillside",
"hilly",
"history",
"historian",
"historic",
"historical",
"histories",
"hold",
"held",
"holders",
"holding",
"holds",
"home",
"homeless",
"homes",
"honour",
"dishonour",
"dishonourable",
"honor",
"honorable",
"honorably",
"honorary",
"honored",
"honoring",
"honors",
"honourable",
"honourably",
"hope",
"hoped",
"hopeful",
"hopeless",
"hopelessness",
"hopes",
"hoping",
"horse",
"horses",
"hot",
"hotly",
"hotness",
"hotter",
"hottest",
"hour",
"hourly",
"hours",
"house",
"housed",
"housing",
"houses",
"how",
"however",
"human",
"humans",
"hundred",
"hundreds",
"hundredth",
"husband",
"husbands",
"i",
"me",
"mine",
"my",
"myself",
"idea",
"ideas",
"if",
"ill",
"illness",
"illnesses",
"important",
"importance",
"unimportant",
"unimportance",
"importantly",
"in",
"inner",
"inch",
"inches",
"include",
"included",
"includes",
"including",
"inclusive",
"inclusion",
"increase",
"increased",
"increases",
"increasing",
"increasingly",
"indeed",
"independent",
"independently",
"independence",
"industry",
"industrial",
"industrially",
"industries",
"influence",
"influenced",
"influences",
"influencing",
"influential",
"instead",
"interest",
"interested",
"interesting",
"interests",
"into",
"introduce",
"introduced",
"introduces",
"introducing",
"introduction",
"introductions",
"introductory",
"iron",
"it",
"its",
"itself",
"j",
"january",
"jan",
"join",
"joined",
"joining",
"joins",
"joint",
"jointed",
"disjointed",
"joints",
"jointly",
"joy",
"joyful",
"joyfully",
"joys",
"judge",
"judged",
"judges",
"judging",
"judgment",
"judgments",
"judgement",
"judgements",
"judgemental",
"july",
"june",
"just",
"justly",
"unjust",
"unjustly",
"justice",
"k",
"keep",
"keepers",
"keeping",
"keeps",
"kept",
"kill",
"killed",
"killer",
"killers",
"killing",
"kills",
"kind",
"kindly",
"kindness",
"kinds",
"king",
"kings",
"kingdom",
"kingdoms",
"know",
"knew",
"knowing",
"knowledge",
"known",
"knows",
"unknown",
"knowledgeable",
"l",
"lack",
"lacked",
"lacking",
"lacks",
"lady",
"ladies",
"lake",
"lakes",
"land",
"landed",
"landing",
"lands",
"landlords",
"language",
"languages",
"large",
"largely",
"larger",
"largest",
"last",
"lasted",
"lasting",
"lasts",
"lastly",
"late",
"lately",
"lateness",
"later",
"latest",
"latter",
"laugh",
"laughs",
"laughed",
"laughing",
"laughable",
"laughter",
"law",
"laws",
"lawyer",
"lawyers",
"lawful",
"lawfully",
"unlawful",
"lawless",
"lay",
"laid",
"laying",
"lays",
"lead",
"leaded",
"leader",
"leaders",
"leadership",
"leading",
"leads",
"mislead",
"misleading",
"misled",
"led",
"learn",
"learned",
"learner",
"learners",
"learning",
"learns",
"learnt",
"leave",
"leaves",
"leaving",
"left",
"leftist",
"leftists",
"length",
"lengthening",
"lengths",
"lengthy",
"lengthen",
"less",
"lessen",
"lessened",
"lessening",
"lesser",
"least",
"let",
"lets",
"letting",
"letter",
"letters",
"level",
"levelled",
"leveller",
"levelling",
"levels",
"library",
"librarian",
"librarians",
"libraries",
"lie",
"liar",
"liars",
"lied",
"lies",
"lying",
"life",
"lifetime",
"lifetimes",
"lifelike",
"lifelong",
"lift",
"lifted",
"lifting",
"lifts",
"light",
"lighted",
"lighten",
"lighter",
"lightest",
"lighting",
"lightly",
"lightness",
"lights",
"lightweight",
"lit",
"like",
"liked",
"likes",
"liking",
"unlike",
"dislike",
"dislikes",
"disliked",
"disliking",
"likely",
"likelier",
"likeliest",
"likelihood",
"unlikely",
"limit",
"limitation",
"limitations",
"limited",
"limiting",
"limits",
"unlimited",
"line",
"lines",
"lined",
"lining",
"lip",
"lips",
"listen",
"listened",
"listener",
"listeners",
"listening",
"listens",
"literature",
"literary",
"little",
"littler",
"littlest",
"live",
"lived",
"liveliest",
"lively",
"lives",
"living",
"local",
"locally",
"locals",
"long",
"longer",
"longest",
"look",
"looked",
"looking",
"looks",
"outlook",
"lord",
"lords",
"lordship",
"lordships",
"lose",
"losers",
"loses",
"losing",
"lost",
"loss",
"losses",
"love",
"loved",
"lovely",
"loves",
"loving",
"lovable",
"lover",
"low",
"lower",
"lowered",
"lowest",
"lowering",
"machine",
"machinery",
"machines",
"main",
"mainly",
"make",
"made",
"maker",
"makers",
"makes",
"making",
"man",
"mankind",
"men",
"manly",
"manhood",
"manliness",
"manner",
"manners",
"manufacture",
"manufactured",
"manufacturing",
"manufactures",
"manufacturers",
"manufacturer",
"many",
"march",
"marched",
"marchers",
"marches",
"marching",
"mark",
"marked",
"marker",
"markers",
"marking",
"marks",
"market",
"marketed",
"marketing",
"markets",
"marry",
"marriage",
"marriages",
"married",
"marries",
"marrying",
"mass",
"masses",
"master",
"masters",
"mastered",
"mastering",
"masterful",
"mastery",
"material",
"materialistic",
"materialistically",
"materially",
"materials",
"matter",
"mattered",
"mattering",
"matters",
"may",
"maybe",
"mean",
"meaner",
"meanest",
"meaning",
"meaningful",
"meaningless",
"meanings",
"meanly",
"meanness",
"means",
"meant",
"measure",
"measured",
"measurement",
"measurements",
"measures",
"measurable",
"measurably",
"measuring",
"meet",
"meeting",
"meetings",
"meets",
"met",
"member",
"members",
"membership",
"memberships",
"memory",
"memorial",
"memories",
"memorise",
"memorised",
"memorises",
"memorising",
"memorize",
"memorized",
"memorizes",
"memorizing",
"memorials",
"mention",
"mentioned",
"mentioning",
"mentions",
"unmentioned",
"mere",
"merely",
"merest",
"metal",
"metals",
"middle",
"mid",
"midnight",
"midst",
"might",
"mile",
"miles",
"milk",
"milky",
"milked",
"milks",
"milking",
"million",
"millions",
"millionth",
"mind",
"minded",
"minding",
"minds",
"miner",
"miners",
"mined",
"mining",
"mines",
"minister",
"ministers",
"minute",
"minutes",
"miss",
"missed",
"misses",
"missing",
"mister",
"mr",
"modern",
"modernise",
"modernisation",
"moment",
"momentary",
"moments",
"monday",
"mon",
"mondays",
"money",
"month",
"monthly",
"months",
"moon",
"moons",
"moonlight",
"moral",
"morals",
"morally",
"morality",
"more",
"moreover",
"morning",
"mornings",
"most",
"mostly",
"mother",
"mother-in-law",
"mothers",
"mom",
"motherhood",
"mum",
"motor",
"motorist",
"motorists",
"motors",
"mountain",
"mountains",
"mountainside",
"mt",
"mouth",
"mouthful",
"mouths",
"move",
"moved",
"movement",
"moves",
"moving",
"movements",
"mrs",
"ms",
"much",
"music",
"musical",
"musician",
"musicians",
"musically",
"must",
"name",
"named",
"names",
"naming",
"namely",
"nameless",
"nation",
"national",
"nationally",
"nationwide",
"nations",
"native",
"natives",
"nature",
"natural",
"naturally",
"natures",
"near",
"nearby",
"nearer",
"nearest",
"nearly",
"nearness",
"necessary",
"necessarily",
"unnecessarily",
"unnecessary",
"necessity",
"necessities",
"need",
"needed",
"needing",
"needless",
"needs",
"neighbour",
"neighbor",
"neighborhood",
"neighborhoods",
"neighbors",
"neighbourhood",
"neighbourhoods",
"neighbours",
"neither",
"never",
"new",
"newer",
"newest",
"newly",
"newness",
"renew",
"renewed",
"renews",
"renewing",
"news",
"newspaper",
"newspapers",
"next",
"night",
"nightly",
"nights",
"nine",
"nines",
"nineteen",
"nineteenth",
"nineties",
"ninetieth",
"ninety",
"ninth",
"no",
"nobody",
"nothing",
"nowhere",
"noble",
"nobility",
"nobler",
"noblest",
"nobly",
"nobles",
"none",
"nor",
"north",
"north-east",
"north-west",
"northeast",
"northern",
"northwards",
"northwest",
"not",
"t",
"note",
"notable",
"notes",
"noting",
"notably",
"noted",
"notice",
"noticeable",
"noticeably",
"noticed",
"notices",
"noticing",
"november",
"nov",
"now",
"nowadays",
"number",
"numbered",
"numbering",
"numbers",
"numerous",
"numerical",
"numerically",
"o",
"object",
"objected",
"objection",
"objecting",
"objects",
"objectionable",
"objections",
"observe",
"observable",
"observation",
"observations",
"observatory",
"observed",
"observer",
"observers",
"observes",
"observing",
"occasion",
"occasional",
"occasionally",
"occasions",
"october",
"oct",
"of",
"off",
"offer",
"offered",
"offering",
"offerings",
"offers",
"office",
"officer",
"officers",
"offices",
"official",
"officially",
"officialdom",
"officials",
"often",
"oh",
"oil",
"oily",
"oiliness",
"oils",
"oiled",
"old",
"older",
"oldest",
"on",
"onto",
"once",
"one",
"ones",
"only",
"open",
"opening",
"openly",
"openness",
"opens",
"opened",
"operate",
"operated",
"operates",
"operating",
"operation",
"operations",
"operator",
"operators",
"operational",
"operative",
"opinion",
"opinions",
"opinionated",
"opportunity",
"opportunities",
"or",
"order",
"ordered",
"ordering",
"orderly",
"orders",
"ordinary",
"ordinarily",
"organize",
"organisation",
"organisations",
"organise",
"organised",
"organises",
"organising",
"organization",
"organizations",
"organized",
"organizes",
"organizing",
"organisational",
"other",
"others",
"otherwise",
"ought",
"out",
"outer",
"outside",
"outsider",
"outsiders",
"outward",
"outwards",
"over",
"owe",
"owed",
"owes",
"owing",
"own",
"owned",
"owner",
"owners",
"ownership",
"owning",
"owns",
"p",
"page",
"pages",
"paint",
"painted",
"painter",
"painters",
"painting",
"paintings",
"paints",
"paper",
"papers",
"papered",
"papering",
"part",
"parted",
"parting",
"partly",
"parts",
"partial",
"partially",
"particle",
"particles",
"particular",
"particularly",
"party",
"parties",
"pass",
"passed",
"passes",
"passing",
"past",
"pay",
"paid",
"paying",
"payment",
"payments",
"pays",
"repaid",
"unpaid",
"peace",
"peaceful",
"peacefully",
"people",
"peoples",
"per",
"perhaps",
"permit",
"permission",
"permits",
"permitted",
"permitting",
"person",
"personal",
"personalities",
"personally",
"persons",
"picture",
"pictured",
"pictures",
"picturing",
"piece",
"pieces",
"place",
"placed",
"places",
"placing",
"plain",
"plainly",
"plains",
"plan",
"planned",
"planner",
"planners",
"planning",
"plans",
"plant",
"planted",
"planting",
"plants",
"play",
"played",
"player",
"players",
"playing",
"plays",
"replay",
"replays",
"replaying",
"replayed",
"please",
"pleasant",
"pleasantly",
"pleasantness",
"pleased",
"pleases",
"pleasing",
"pleasure",
"unpleasant",
"unpleasantly",
"displease",
"displeased",
"displeasing",
"displeasure",
"point",
"pointed",
"pointing",
"points",
"pointer",
"pointers",
"political",
"politically",
"politician",
"politicians",
"politics",
"poor",
"poorer",
"poorest",
"poorly",
"poverty",
"popular",
"popularity",
"popularly",
"population",
"populations",
"populate",
"populating",
"populated",
"populates",
"position",
"positions",
"positioning",
"positioned",
"possess",
"possessed",
"possesses",
"possessing",
"possession",
"possessions",
"possible",
"possibilities",
"possibility",
"possibly",
"impossibility",
"impossible",
"impossibly",
"post",
"posted",
"poster",
"posters",
"posting",
"posts",
"pound",
"pounds",
"power",
"powered",
"powerful",
"powers",
"prepare",
"preparation",
"preparations",
"prepared",
"prepares",
"preparing",
"unprepared",
"present",
"presence",
"presentation",
"presented",
"presenting",
"presently",
"presents",
"president",
"presidents",
"presidential",
"press",
"pressed",
"presses",
"pressing",
"pressure",
"pressured",
"pressures",
"pressuring",
"pretty",
"prettier",
"prettiest",
"prettily",
"prettiness",
"prevent",
"prevented",
"preventing",
"prevention",
"prevents",
"preventable",
"preventative",
"unpreventable",
"price",
"priced",
"prices",
"pricing",
"private",
"privately",
"problem",
"problems",
"problematic",
"produce",
"produced",
"producer",
"producers",
"produces",
"producing",
"product",
"products",
"production",
"productions",
"productive",
"productivity",
"profit",
"profited",
"profiting",
"profits",
"profitable",
"progress",
"progressed",
"progresses",
"progressing",
"progressive",
"progressively",
"promise",
"promised",
"promises",
"promising",
"proper",
"properly",
"improper",
"improperly",
"property",
"properties",
"propose",
"proposal",
"proposals",
"proposed",
"proposes",
"proposing",
"protect",
"protected",
"protecting",
"protection",
"protections",
"protective",
"protects",
"prove",
"proved",
"proves",
"proving",
"unproven",
"proof",
"proofs",
"provide",
"provided",
"provides",
"providing",
"provider",
"providers",
"provision",
"provisions",
"public",
"publicity",
"publicly",
"pull",
"pulled",
"pulling",
"pulls",
"purpose",
"purposes",
"put",
"puts",
"putting",
"q",
"quality",
"qualities",
"quantity",
"quantities",
"quarter",
"quarterly",
"quarters",
"queen",
"queens",
"question",
"questions",
"questioned",
"questioning",
"questionable",
"quite",
"r",
"race",
"racecourse",
"raced",
"races",
"racing",
"raise",
"raised",
"raises",
"raising",
"rank",
"ranked",
"ranking",
"ranks",
"rate",
"rated",
"rates",
"rating",
"rather",
"reach",
"reached",
"reaches",
"reaching",
"read",
"reader",
"readers",
"reading",
"readings",
"reads",
"ready",
"readily",
"real",
"realistic",
"reality",
"realise",
"realize",
"realization",
"realized",
"realizes",
"realizing",
"realisation",
"realisations",
"realised",
"realising",
"realises",
"really",
"reason",
"reasonable",
"reasonably",
"reasoned",
"reasoning",
"reasons",
"receive",
"received",
"receiver",
"receives",
"receiving",
"receipt",
"receipts",
"recent",
"recently",
"recognize",
"recognise",
"recognised",
"recognises",
"recognising",
"recognition",
"recognized",
"recognizes",
"recognizing",
"record",
"recorded",
"recording",
"records",
"red",
"redder",
"reddest",
"redness",
"redden",
"reddish",
"reduce",
"reduced",
"reduces",
"reducing",
"reduction",
"reductions",
"refuse",
"refusal",
"refusals",
"refused",
"refuses",
"refusing",
"regard",
"disregard",
"disregarded",
"disregarding",
"disregards",
"regarded",
"regarding",
"regardless",
"regards",
"relation",
"relate",
"related",
"relates",
"relating",
"relations",
"relationship",
"relationships",
"relative",
"relatively",
"relatives",
"religion",
"religions",
"religious",
"remain",
"remained",
"remaining",
"remainder",
"remainders",
"remains",
"remark",
"remarked",
"remarking",
"remarks",
"remarkable",
"remarkably",
"remember",
"remembered",
"remembering",
"remembers",
"reply",
"replied",
"replies",
"replying",
"report",
"reported",
"reporter",
"reporters",
"reporting",
"reports",
"represent",
"representative",
"representatives",
"represented",
"representing",
"represents",
"representation",
"representations",
"republic",
"republics",
"republican",
"republicans",
"republicanism",
"reserve",
"reserves",
"reservation",
"reservations",
"reserved",
"reserving",
"respect",
"disrespect",
"disrespectful",
"respected",
"respecting",
"respects",
"respectful",
"respectable",
"respectfully",
"respective",
"respectively",
"irrespective",
"irrespectively",
"rest",
"rested",
"resting",
"restless",
"restlessness",
"rests",
"result",
"resulted",
"resulting",
"results",
"return",
"returned",
"returning",
"returns",
"rich",
"richer",
"richest",
"richly",
"richness",
"riches",
"ride",
"ridden",
"rider",
"riders",
"rides",
"riding",
"rode",
"right",
"rightful",
"rightfully",
"rightist",
"rightists",
"rightly",
"rights",
"ring",
"rang",
"ringed",
"ringing",
"rings",
"rung",
"rise",
"rises",
"rising",
"rose",
"river",
"rivers",
"riverside",
"road",
"roads",
"roadside",
"rock",
"rocky",
"rocked",
"rocking",
"rocks",
"roll",
"rolled",
"rolling",
"rolls",
"roller",
"rollers",
"room",
"rooms",
"rough",
"roughly",
"roughness",
"round",
"rounded",
"rounder",
"roundest",
"roundly",
"roundness",
"rounds",
"roundabout",
"royal",
"royalty",
"royally",
"rule",
"ruled",
"ruler",
"rulers",
"rules",
"ruling",
"run",
"ran",
"runner",
"runners",
"running",
"runs",
"safe",
"safely",
"safeness",
"safer",
"safest",
"safety",
"sail",
"sailed",
"sailing",
"sailings",
"sailor",
"sailors",
"sails",
"sale",
"sales",
"salt",
"salty",
"same",
"sameness",
"saturday",
"saturdays",
"save",
"saved",
"saves",
"saving",
"savings",
"say",
"said",
"saying",
"says",
"scarce",
"scarcely",
"scarcer",
"scarcest",
"scarcity",
"scene",
"scenery",
"scenes",
"school",
"schooling",
"schools",
"science",
"sciences",
"scientific",
"scientist",
"scientists",
"scientifically",
"sea",
"seaman",
"seaside",
"seamen",
"seas",
"season",
"seasons",
"seat",
"seated",
"seating",
"seats",
"second",
"secondary",
"secondly",
"seconds",
"secret",
"secrecy",
"secretly",
"secrets",
"secretary",
"secretaries",
"see",
"saw",
"seeing",
"seen",
"sees",
"unseen",
"seem",
"seemed",
"seeming",
"seems",
"sell",
"seller",
"sellers",
"selling",
"sells",
"sold",
"resell",
"reselling",
"resold",
"send",
"sender",
"senders",
"sending",
"sends",
"sent",
"sense",
"senseless",
"senselessness",
"senses",
"sensible",
"sensitive",
"sensitivity",
"separate",
"separated",
"separately",
"separates",
"separating",
"separation",
"separations",
"separatist",
"separatists",
"september",
"sept",
"serious",
"seriously",
"seriousness",
"serve",
"servant",
"servants",
"served",
"serves",
"serving",
"servings",
"service",
"services",
"serviced",
"servicing",
"set",
"sets",
"setting",
"settle",
"settled",
"settlement",
"settlements",
"settler",
"settlers",
"settles",
"settling",
"seven",
"seventeen",
"seventeenth",
"seventh",
"seventies",
"seventieth",
"seventy",
"several",
"shadow",
"shadowed",
"shadowing",
"shadows",
"shadowy",
"shake",
"shaken",
"shakes",
"shakily",
"shaking",
"shaky",
"shook",
"shall",
"shan",
"shape",
"shaped",
"shapes",
"shaping",
"shapeless",
"share",
"shared",
"shares",
"sharing",
"she",
"her",
"hers",
"herself",
"shine",
"shined",
"shines",
"shining",
"shone",
"shiny",
"ship",
"ships",
"shipping",
"shipped",
"shipments",
"shipment",
"shoot",
"shooting",
"shootings",
"shoots",
"shot",
"shots",
"shore",
"shores",
"short",
"shortage",
"shorten",
"shortened",
"shortening",
"shortens",
"shorter",
"shortest",
"shortly",
"shortness",
"should",
"shoulder",
"shoulders",
"show",
"showed",
"showing",
"shown",
"shows",
"side",
"sides",
"sight",
"sights",
"sign",
"signature",
"signatures",
"signed",
"signing",
"signs",
"silence",
"silenced",
"silences",
"silencing",
"silent",
"silently",
"silver",
"simple",
"simpleness",
"simpler",
"simplest",
"simplicity",
"simplification",
"simplified",
"simplify",
"simply",
"since",
"sing",
"sings",
"sung",
"sang",
"singer",
"singers",
"singing",
"song",
"songs",
"single",
"singled",
"sir",
"sister",
"sisters",
"sisterly",
"sit",
"sat",
"sits",
"sitting",
"situation",
"situations",
"situate",
"situated",
"six",
"sixes",
"sixteen",
"sixteenth",
"sixteenths",
"sixth",
"sixthly",
"sixths",
"sixties",
"sixtieth",
"sixtieths",
"sixty",
"size",
"sizes",
"sizing",
"sized",
"sky",
"skies",
"sleep",
"sleeping",
"sleeps",
"sleepy",
"slept",
"sleepless",
"small",
"smaller",
"smallest",
"smallness",
"smile",
"smiled",
"smiles",
"smiling",
"snow",
"snows",
"snowed",
"snowing",
"so",
"social",
"socially",
"society",
"societies",
"soft",
"soften",
"softened",
"softening",
"softens",
"softer",
"softest",
"softly",
"softness",
"soldier",
"soldiers",
"some",
"somebody",
"somehow",
"someone",
"something",
"sometime",
"sometimes",
"somewhere",
"son",
"sons",
"soon",
"sooner",
"soonest",
"sort",
"sorted",
"sorting",
"sorts",
"soul",
"souls",
"sound",
"sounds",
"sounded",
"sounding",
"south",
"southeast",
"southern",
"southerners",
"southward",
"southwards",
"southwest",
"space",
"spaced",
"spaces",
"spacing",
"speak",
"speaker",
"speakers",
"speaking",
"speaks",
"speech",
"speeches",
"spoke",
"spoken",
"special",
"specially",
"specialist",
"speciality",
"specialities",
"specialists",
"specialize",
"specialization",
"specialized",
"specializations",
"speed",
"sped",
"speeding",
"speeds",
"speedy",
"spend",
"spending",
"spends",
"spent",
"spirit",
"spirits",
"spiritual",
"spite",
"spot",
"spots",
"spotted",
"spotting",
"spread",
"spreading",
"spreads",
"spring",
"sprang",
"springing",
"springs",
"sprung",
"square",
"squarely",
"squareness",
"squarer",
"squares",
"squarest",
"stage",
"staging",
"staged",
"stages",
"stand",
"outstanding",
"standing",
"stands",
"stood",
"standard",
"standards",
"star",
"starred",
"stars",
"starring",
"start",
"started",
"starting",
"starts",
"state",
"stated",
"statement",
"statements",
"states",
"stating",
"station",
"stations",
"stay",
"stayed",
"staying",
"stays",
"steel",
"step",
"stepped",
"stepping",
"steps",
"still",
"stiller",
"stillest",
"stillness",
"stock",
"stocked",
"stocks",
"stone",
"stoned",
"stones",
"stoning",
"stony",
"stop",
"stopped",
"stopping",
"stops",
"store",
"stored",
"stores",
"storing",
"story",
"stories",
"strange",
"strangely",
"strangeness",
"stranger",
"strangers",
"strangest",
"stream",
"streamed",
"streaming",
"streams",
"street",
"streets",
"strength",
"strengthen",
"strengthened",
"strengthening",
"strengthens",
"strike",
"strikes",
"striking",
"struck",
"stroke",
"strong",
"stronger",
"strongest",
"strongly",
"struggle",
"struggled",
"struggles",
"struggling",
"study",
"studied",
"studies",
"studying",
"student",
"students",
"subject",
"subjected",
"subjecting",
"subjects",
"substance",
"substances",
"substantial",
"substantially",
"substantive",
"succeed",
"succeeded",
"succeeding",
"succeeds",
"success",
"successful",
"successfully",
"unsuccessful",
"such",
"suffer",
"suffered",
"suffering",
"suffers",
"suggest",
"suggested",
"suggesting",
"suggestion",
"suggestions",
"suggests",
"summer",
"summers",
"sun",
"sunlight",
"sunny",
"suns",
"sunshine",
"sunday",
"sundays",
"supply",
"supplied",
"supplier",
"suppliers",
"supplies",
"supplying",
"support",
"supported",
"supporters",
"supporting",
"supports",
"supportive",
"suppose",
"supposed",
"supposes",
"supposing",
"sure",
"surely",
"sureness",
"surer",
"surest",
"unsure",
"surface",
"surfaced",
"surfaces",
"surfacing",
"surprise",
"surprised",
"surprises",
"surprising",
"surprisingly",
"surround",
"surrounded",
"surrounding",
"surrounds",
"sweet",
"sweetness",
"sweetly",
"sweets",
"sword",
"swords",
"system",
"systematic",
"systems",
"systematically",
"table",
"tablecloth",
"tables",
"take",
"taken",
"takes",
"taking",
"took",
"talk",
"talked",
"talking",
"talks",
"tax",
"taxes",
"taxed",
"taxing",
"taxpayer",
"taxpayers",
"teach",
"taught",
"teacher",
"teachers",
"teaches",
"teaching",
"teachings",
"tear",
"tearing",
"tears",
"tore",
"torn",
"tell",
"retell",
"retelling",
"telling",
"tells",
"told",
"temple",
"temples",
"ten",
"tens",
"tenth",
"tenths",
"term",
"terms",
"test",
"tested",
"testing",
"tests",
"than",
"the",
"then",
"there",
"therefore",
"they",
"their",
"theirs",
"them",
"themselves",
"thing",
"things",
"think",
"thinking",
"thinks",
"thought",
"thoughts",
"thoughtful",
"thoughtfully",
"thoughtfulness",
"thirteen",
"thirteenth",
"thirteenths",
"thirty",
"thirties",
"thirtieth",
"thirtieths",
"this",
"these",
"those",
"that",
"though",
"thousand",
"thousands",
"thousandth",
"thousandths",
"three",
"threes",
"third",
"thirdly",
"thirds",
"through",
"throughout",
"throw",
"threw",
"throwing",
"thrown",
"throws",
"thursday",
"thurs",
"thursdays",
"thus",
"till",
"time",
"timer",
"times",
"timeless",
"timely",
"to",
"today",
"together",
"ton",
"tons",
"too",
"top",
"topped",
"topping",
"tops",
"total",
"totaled",
"totaling",
"totalled",
"totalling",
"totally",
"totals",
"totality",
"touch",
"touched",
"touches",
"touching",
"untouched",
"toward",
"towards",
"town",
"towns",
"trade",
"traded",
"trades",
"trading",
"trader",
"traders",
"train",
"trained",
"trainers",
"training",
"trains",
"travel",
"traveled",
"traveling",
"travelled",
"travellers",
"travelling",
"travels",
"tree",
"trees",
"trouble",
"troubled",
"troubles",
"troubling",
"troublesome",
"true",
"truthful",
"truth",
"truest",
"truer",
"truthfulness",
"truly",
"truths",
"trust",
"trusted",
"trusting",
"entrust",
"trusts",
"try",
"tried",
"tries",
"trying",
"trial",
"trials",
"trialing",
"trialed",
"tuesday",
"tues",
"tuesdays",
"turn",
"turned",
"turning",
"turns",
"twelve",
"twelves",
"twelfth",
"twelfths",
"twenty",
"twenties",
"twentieth",
"two",
"twice",
"type",
"typed",
"types",
"typing",
"typist",
"typists",
"u",
"under",
"underneath",
"understand",
"understanding",
"understands",
"understood",
"union",
"unions",
"unite",
"united",
"unites",
"uniting",
"unity",
"unit",
"units",
"university",
"universities",
"unless",
"until",
"up",
"upside",
"upon",
"use",
"misused",
"used",
"useful",
"usefulness",
"useless",
"uses",
"using",
"usefully",
"user",
"users",
"usual",
"usually",
"unusual",
"unusually",
"v",
"valley",
"valleys",
"value",
"valuable",
"valuables",
"valuation",
"valued",
"valuer",
"valueless",
"values",
"valuing",
"invaluable",
"invaluably",
"variety",
"varieties",
"various",
"variously",
"very",
"vessel",
"vessels",
"victory",
"victories",
"victorious",
"view",
"viewed",
"viewing",
"views",
"village",
"villager",
"villagers",
"villages",
"virtue",
"virtues",
"virtuous",
"visit",
"visited",
"visiting",
"visitor",
"visitors",
"visits",
"visitation",
"voice",
"voiced",
"voices",
"voicing",
"voiceless",
"vote",
"voted",
"voter",
"voters",
"votes",
"voting",
"w",
"wage",
"wages",
"unwaged",
"wait",
"waited",
"waiting",
"waits",
"waiter",
"waiters",
"waitress",
"waitresses",
"walk",
"walked",
"walking",
"walks",
"wall",
"walled",
"walls",
"want",
"wanted",
"wanting",
"wants",
"unwanted",
"war",
"warred",
"warring",
"wars",
"watch",
"watched",
"watches",
"watching",
"water",
"watered",
"waters",
"watering",
"wave",
"waved",
"waves",
"waving",
"way",
"ways",
"we",
"our",
"ours",
"ourselves",
"us",
"wealth",
"wealthy",
"wear",
"wearing",
"wears",
"wore",
"worn",
"wednesday",
"wednesdays",
"week",
"weekend",
"weekends",
"weekly",
"weeks",
"welcome",
"welcomed",
"welcomes",
"welcoming",
"unwelcome",
"well",
"wells",
"west",
"westward",
"westwards",
"western",
"westerns",
"what",
"whatever",
"when",
"whenever",
"where",
"wherever",
"whether",
"which",
"whichever",
"while",
"whilst",
"white",
"whiteness",
"whiter",
"whitest",
"whitish",
"who",
"whoever",
"whom",
"whose",
"whole",
"wholeness",
"wholly",
"why",
"wide",
"widely",
"widened",
"wideness",
"widening",
"wider",
"widest",
"width",
"wife",
"wives",
"wild",
"wilder",
"wildest",
"wildly",
"wildness",
"will",
"ll",
"willing",
"willingness",
"willingly",
"unwilling",
"unwillingly",
"win",
"winner",
"winners",
"winning",
"wins",
"won",
"wind",
"winded",
"winding",
"winds",
"windy",
"window",
"windows",
"winter",
"winters",
"wintry",
"wise",
"unwise",
"wisdom",
"wisely",
"wiser",
"wisest",
"wish",
"wished",
"wishes",
"wishing",
"with",
"within",
"without",
"woman",
"women",
"wonder",
"wondered",
"wonderful",
"wondering",
"wonders",
"wonderfully",
"wood",
"woods",
"wooden",
"woodland",
"woody",
"word",
"words",
"wording",
"work",
"worked",
"worker",
"workers",
"working",
"works",
"workman",
"workmen",
"world",
"worlds",
"worth",
"worthy",
"worthless",
"would",
"wound",
"wounds",
"wounded",
"wounding",
"write",
"writer",
"writers",
"writes",
"writing",
"writings",
"written",
"wrote",
"wrong",
"wronged",
"wronging",
"wrongs",
"wrongly",
"y",
"year",
"years",
"yearly",
"yield",
"yields",
"yielded",
"yielding",
"yes",
"yesterday",
"yet",
"you",
"your",
"yourselves",
"yourself",
"yours",
"young",
"younger",
"youngster",
"youngest",
"youngsters",
"youth",
"youths",
"youthful",
"aren",
"isn",
"wasn",
"weren",
"unbusinesslike",
"centerist",
"centerists",
"couldn",
"didn",
"doesn",
"hadn",
"hasn",
"ve",
"lifesize",
"mightn",
"needn",
"noone",
"oughtn",
"proven",
"shouldn",
"wiseness",
"wouldn",
}

is_word_gsl1 = lambda w : w in word_gsl1

def submit(port, host='127.0.0.1',  db=0):
	import redis
	r = redis.Redis(host=host, port=port, db=db)
	for w in word_gsl1: 
		r.sadd("dict:gsl1", w )
		r.hset('dict:word_level', w, 'gsl1')
	print(">> finished loading gsl1")

if __name__ == '__main__':
	submit(6311)


# 2022.3.2
import json,requests,fire,hashlib
from uvirun import * 
feedbacks = lambda dic :  [ v for k,v in dic['feedback'].items() ]

@app.get("/dsk/feedback")
def dsk_feedback(text:str="The quick fox jumped over the lazy dog. The justice delayed is justice denied."):
	''' '''
	dsk = requests.post(f"http://{fire.dskurl}/essay/gecdsk", json={"rid":"10", "key": hashlib.md5(text.encode("utf-8")).hexdigest(), "essay":text}).json()
	return  [ ( dic.get('meta',{}).get('snt',''), feedbacks(dic) ) for dic in dsk['snt']]

def run(port, dskurl, host='0.0.0.0'):
	''' '''
	print (port, dskurl, flush=True) 
	fire.dskurl = dskurl 
	uvicorn.run(app, host=host, port=port)

if __name__ == "__main__":  
	fire.Fire(run)


stoplist={',', '.', ';','"', "'",'!', '?', 'very','ourselves','am','doesn','through','me','against','up','just','her','ours','couldn','because','is','isn','it','only','in',
'such','too','mustn','under','their','if','to','my','himself','after','why','while','can','each','itself','his','all','once','herself','more',
'our','they','hasn','on','ma','them','its','where','did','ll','you','didn','nor','as','now','before','those','yours','from','who','was','m',
'been','will','into','same','how','some','of','out','with','s','being','t','mightn','she','again','be','by','shan','have','yourselves','needn',
'and','are','o','these','further','most','yourself','having','aren','here','he','were','but','this','myself','own','we','so','i','does','both',
'when','between','d','had','the','y','has','down','off','than','haven','whom','wouldn','should','ve','over','themselves','few','then','hadn',
'what','until','won','no','about','any','that','for','shouldn','don','do','there','doing','an','or','ain','hers','wasn','weren','above','a',
'at','your','theirs','below','other','not','re','him','during','which',
"\n", "\r", "\n\n"}

def feed_pika():
	import redis
	r = redis.Redis(host='dev.werror.com', db=0, port=8008,  decode_responses=True)
	for w in stoplist : r.sadd('stoplist', w )
	print("done")

if __name__ == '__main__': 
	feed_pika()


#pip install -U sentence-transformers
import fire ,json, requests
from sentence_transformers import SentenceTransformer
model = SentenceTransformer('all-MiniLM-L6-v2')

config = {  
		"settings" : {
			"refresh_interval": "1s",
			"number_of_shards": "3",
			"max_result_window":"2147483647",
			"index.mapping.ignore_malformed": "true",
			"analysis": {
			  "filter": {
				"postag_filter": {
				  "type": "pattern_capture",
				  "preserve_original": "false",
				  "patterns": [
					"(^([^_]+)_[a-z]+[,\\.$]?)",
					"(_[a-z\\-\\.\\'\\$0-9]+)$",
					"(_[a-z\\-\\.\\'\\$]+)",
					"(_[^\\w]+)_",
					"([^\\w])_"
				  ]
				},
				"postag_filter2": {
				  "type": "word_delimiter",
				  "type_table": [
					"^ => ALPHA",
					", => ALPHA",
					"$ => ALPHA",
					"_ => ALPHA",
					". => ALPHA",
					"- => ALPHA",
					"! => ALPHA",
					"? => ALPHA",
					"' => ALPHA",
					"0 => ALPHA",
					"1 => ALPHA",
					"2 => ALPHA",
					"3 => ALPHA",
					"4 => ALPHA",
					"5 => ALPHA",
					"6 => ALPHA",
					"7 => ALPHA",
					"8 => ALPHA",
					"9 => ALPHA"
				  ]
				},
				"unique_filter": {
				  "type": "unique",
				  "only_on_same_position": "true"
				}
			  },
			  "analyzer": {
				"postag_ana": {"filter": ["lowercase","postag_filter", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" },
				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
				"err_ana": {"type": "custom",  "tokenizer": "path-tokenizer1"  },
				"chunk_ana": {"type": "custom", "tokenizer": "path-tokenizer2" },
				"kp_ana": { "filter": ["lowercase"], "type": "custom", "tokenizer": "keyword"}
			  },
			  "tokenizer": {
				"path-tokenizer": { "type": "path_hierarchy",  "delimiter": "/" },
				"path-tokenizer1": {"type": "path_hierarchy",  "delimiter": "|" },
				"path-tokenizer2": {"type": "path_hierarchy",  "delimiter": "/" },
				"feedback-tokenizer": { "type": "path_hierarchy",  "delimiter": "." }
				}
			},
			"number_of_replicas": "0"
		},
		"mappings" : {
			"_source": {"excludes": ["md5"]},
			"properties": {
			 "@timestamp":{"format":"strict_date_optional_time||epoch_millis", "type":"date"},
			"errs": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
			"kps": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
			"i": { "type": "integer"},
			"score": { "type": "float"},
			"offset": { "type": "float"},
			"final_score": { "type": "float"},
			"sid": { "type": "keyword"},
			"id": { "type": "keyword"},
			"rid": { "type": "integer"},
			"did": { "type": "integer"},
			"docid": { "type": "keyword"},
			"uid": { "type": "integer"},
			"eid": { "type": "integer"},
			"sntnum": { "type": "integer"},
			"wordnum": { "type": "integer"},
			"awl": { "type": "float"},
			"cnt": { "type": "long"},
			"vers": { "type": "integer"},
			"ver": { "type": "integer"},
			"ct": { "type": "integer"},
			"lem": { "type": "keyword"},
			"lex": { "type": "keyword"},
			"low": { "type": "keyword"},
			"pos": { "type": "keyword"},
			"tag": { "type": "keyword"},

			"ap": { "type": "keyword"},
			"page": { "type": "keyword"},
			"pen": { "type": "keyword"},
			"label": { "type": "keyword"},
			"item": { "type": "keyword"},
			"lang": { "type": "keyword"},
			"key": { "type": "keyword"},
			"item_key": { "type": "keyword"},
			"score": { "type": "float"},
			"tmf": { "type": "float"},
			"stroke": { "type": "keyword", "index": "false"},
			"strokes": { "type": "keyword", "index": "false"},

			"en": { "type": "text", "analyzer": "standard","fielddata":"true"},
			"content": { "type": "text", "analyzer": "standard","fielddata":"true"},
			"zhseg": { "type": "text", "analyzer": "standard"},
			"zh": { "type": "text", "index": "false"},

			"src": { "type": "keyword"},
			"srcsnt": { "type": "keyword"},
			"segtype": { "type": "keyword"},
			"filename": { "type": "keyword"},
			"fullname": { "type": "keyword"},
			"sect": { "type": "keyword"},
			"index": { "type": "keyword"},
			"corpus": { "type": "keyword"},
			"folder": { "type": "keyword"},
			"head": { "type": "keyword"},
			"chunk": { "type": "keyword"},
			"type": { "type": "keyword"},
			"fn": { "type": "keyword"},
			"cat": { "type": "keyword"},
			"rel": { "type": "keyword"},
			"gov": { "type": "keyword"},
			"dep": { "type": "keyword"},
			"vp": { "type": "keyword"},
			"ap": { "type": "keyword"},
			"dp": { "type": "keyword"},
			"kp": { "type": "keyword"},
			"cate": { "type": "keyword"},
			"feedback": { "type": "keyword"},
			"tail":{ "type": "keyword"},
			"govpos":{ "type": "keyword"},
			"deppos":{ "type": "keyword"},
			"fd": { "type": "keyword"},
			"err": {"type": "text",  "analyzer": "err_ana"},
			"fd": { "type": "keyword"},
			"short_msg": { "type": "keyword"},
			"arr": { "type": "keyword", "index": "false" }, # dim arr of dsk
			"info": { "type": "keyword", "index": "false" ,"store": "false"},
			"kw": { "type": "keyword", "index": "false" ,"store": "false", "ignore_above": 60},
			"meta": { "type": "keyword", "index": "false" ,"store": "false"},
			"tc": {"type": "integer" , "index": "false"},
			"sc": {"type": "integer" , "index": "false"},
			"isum": {"type": "integer" , "index": "false"},
			"md5": { "type": "text", "store": "false", "norms":"false"},
			"toks": { "type": "keyword", "index": "false" ,"store": "false"},
			"snts": { "type": "keyword", "index": "false" ,"store": "false"},
			"blob": { "type": "binary", "store": "false"},
			"zlib": { "type": "binary", "store": "false"},
			"title": { "type": "text", "analyzer": "standard"},
			"essay": { "type": "text", "analyzer": "standard"},
			"body": { "type": "text", "index": "false" },
			"doc": { "type": "text", "index": "false" },#"doc": { "type": "keyword", "index": "false" ,"store": "false"}, # dim arr of dsk
			"tm": { "type": "date"}, #"format": "yyyy-MM-dd HH:mm:ss || yyyy-MM-dd || yyyy/MM/dd HH:mm:ss|| yyyy/MM/dd ||epoch_millis"
			"sdate": { "type": "date",  "format": "yyyy-MM-dd"},
			"csv": { "type": "keyword",  "index": "false"},
			"tsv": { "type": "keyword",  "index": "false"},
			"pair": { "type": "keyword",  "index": "false"},
			"json": { "type": "keyword",  "index": "false"},
			"v": { "type": "keyword",  "index": "false"},
			"n": { "type": "keyword",  "index": "false"},
			"adj": { "type": "keyword",  "index": "false"},
			"snt": { "type": "text", "analyzer": "standard","fielddata":"true"},
			"vec": {
				   "type": "dense_vector",
				   "dims": 384, # use sbert 
				   "index": "true",
				   "similarity": "l2_norm"
				 }
		  }
		}
	}

#es = Elasticsearch(['es.wrask.com:9200'], http_auth=('elastic', 'cikuutest!'), timeout=3600)
from elasticsearch import Elasticsearch,helpers
es = Elasticsearch(  
    "https://localhost:9200",
    ca_certs="/home/ubuntu/http_ca.crt",
	http_auth=('elastic', 'cikuutest!'), timeout=3600 )

from uvirun import * 
app.title = "snt vec search" 
app.tm = "2022.2.18"

@app.get('/sntvec/snt')
def snt_search(snt:str="I'm glad to meet you.", index:str='gzjc', topk:int=10): 
	''' search sent with nearest semantic '''
	vec = model.encode(snt.strip())
	#res = es.search(index=index, body={})
	res = es.knn_search(index=index, source=['snt'],knn={ 
	"field": "vec",
   "query_vector": vec,
   "k": 10,
   "num_candidates": topk})
	return res

@app.get('/sntvec/tovec')
def snt_tovec(snt:str="I'm glad to meet you."): 
	''' search sent with nearest semantic '''
	vec = model.encode(snt.strip())
	return vec.tolist()

@app.get('/sntvec/indexlist')
def index_list(): 
	''' show tables '''
	return es.sql.query(query = "show tables").get('rows',[])

@app.get('/sntvec/delete_by_id')
def delete_by_id(index:str='gzjc', id:str='xxx'): 
	''' delete_by_id '''
	return es.delete(index=index, id=id)

@app.get('/sntvec/add_new_snt')
def add_new_snt(index:str='gzjc', snt:str='Justice delayed is justice denied.'): 
	'''  '''
	vec = model.encode(snt.strip())
	return es.index(index=index, document={"snt":snt, "vec": vec.tolist()})

def readline(infile, sepa=None):
	with open(infile, 'r') as fp:
		while True:
			line = fp.readline()
			if not line: break
			yield line.strip().split(sepa) if sepa else line.strip()

class util(object):
	def __init__(self): pass 

	def vec(self, infile, outfile=None): 
		''' gzjc.snt -> gzjc.vec_source  '''
		if not outfile : outfile = infile.split('.')[0] + ".vec"
		print ("started:", infile, flush=True)
		with open(outfile, 'w') as fw: 
			for line in readline(infile): 
				vec = model.encode(line.strip())
				arr = {'snt': line.strip(), 'vec': vec.tolist()}
				fw.write(json.dumps(arr) + "\n")
		print ("finished:", infile)

	def idsource(self, infile, idxname=None, batch=100000, refresh:bool=True): 
		''' {"_id": "140948871-9", "_source": {"rid": "10", "uid": "25110374", "sc": 14, "md5": "da891a7d81f7a5e43b571168cc483b6c dba0b4c99ef37cadfc4bacd61fcefa5b d6b199bfae35246564c598ac78d84c91 38a945eeff5b5a587a26dcc6560e0061 58605af6b50b01f15c0cc3ee2aa75e33"}}'''
		if not idxname : idxname = infile.split('.')[0] 
		print("idsource started:", infile, idxname, es, flush=True)
		if refresh and es.indices.exists(index=idxname): es.indices.delete(index=idxname)
		if not es.indices.exists(index=idxname): es.indices.create(index=idxname, body=config)
		actions=[]
		for line in readline(infile):  
			try:
				arr = json.loads(line) # 
				if not '_source' in arr : arr = {"_source": arr} # source only njson 
				arr.update({'_op_type':'index', '_index':idxname})
				actions.append(arr)
				if len(actions) > batch : 
					helpers.bulk(client=es,actions=actions, raise_on_error=False)
					actions=[]
					print(arr["_id"], flush=True) 
			except Exception as ex:
				print(">>callback ex:", ex, line)
		helpers.bulk(client=es,actions=actions, raise_on_error=False)
		print("idsource finished:", infile,idxname)

if __name__ == '__main__':
	fire.Fire(util)

'''
uvicorn sntvec:app --host 0.0.0.0 --port 19200 --reload

python sntvec.py idsource gzjc.source  gzjc1

GET gzjc/_knn_search
{
 "knn": {
   "field": "image-vector",
   "query_vector": [-0.5, 9.4, 1,2],
   "k": 10,
   "num_candidates": 100
 }
}

PUT gzjc
{
 "mappings": {
   "properties": {
     "snt":{"type":"text"},
     "vec": {
       "type": "dense_vector",
       "dims": 384,
       "index": true,
       "similarity": "l2_norm"
     }
   }
 }
}

>>> es.get(index='twitter', id='wTxqC38BopRXpF5veeGm')
ObjectApiResponse({'_index': 'twitter', '_id': 'wTxqC38BopRXpF5veeGm', '_version': 1, '_seq_no': 0, '_primary_term': 1, 'found': True, '_source': {'one': 'wo'}})
>>>

>>> res.body
{'_index': 'twitter', '_id': 'wTxqC38BopRXpF5veeGm', '_version': 1, '_seq_no': 0, '_primary_term': 1, 'found': True, '_source': {'one': 'wo'}}

certificate_path = os.path.join(CERT_PATH, 'cacert.pem')
certificate_key_path = os.path.join(CERT_PATH, 'cacert.key')
response = requests.get(url, cert=(certificate_path, certificate_key_path))
'''